@@ -407,7 +407,7 @@ class ExtAllDayField(dd.VirtualField):
 
 class Event(
     Component, Ended, Assignable, TypedPrintable, Mailable, Postable,
-    Publishable, GoogleCalendarEventSynchronized, Draggable, Controllable):
+    Publishable, GoogleCalendarEventSynchronized, Draggable):
 
     class Meta:
         app_label = 'cal'
