@@ -398,7 +398,7 @@ class SiblingsByPerson(Members):
     # column_names = 'person role start_date end_date *'
     order_by = ['birth_date']
     auto_fit_column_widths = True
-    # display_mode = 'summary'
+    # display_mode_main = 'summary'
     window_size = (100, 20)
 
     @classmethod
@@ -535,7 +535,7 @@ class MembersByPerson(Members):
     """
     # auto_fit_column_widths = True
     # hide_columns = 'id'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     stay_in_grid = True
 
     @classmethod
