@@ -6,7 +6,7 @@
 Adds functionality for **invoicing**, i.e. automatically generating
 invoices from data in the database.
 
-See :doc:`/specs/invoicing`.
+See :doc:`/plugins/invoicing`.
 
 """
 
@@ -21,19 +21,35 @@ class Plugin(Plugin):
     # needs_plugins = ['lino_xl.lib.ledger']
     needs_plugins = ['lino_xl.lib.sales']
 
+    order_model = None
+    """
+    The database model that represents a maintenance order.
+
+    In Presto and Noi this is 'orders.Order'.
+    """
+
     voucher_model = 'sales.VatProductInvoice'
     item_model = 'sales.InvoiceItem'
     """
     The database model into which invoiceable objects should create
-    invoice items.  Default value refers to :class:`sales.InvoiceItem
-    <lino_xl.lib.sales.models.InvoiceItem>`.
+    invoice items.  Default value is :class:`sales.InvoiceItem
+    <lino_xl.lib.sales.InvoiceItem>`.
+
+    Lino will inject a :term:`generic foreign key` named :attr:`invoiceable` to
+    this model.
 
-    This model will have an injected GFK field `invoiceable`.
     """
 
     invoiceable_label = _("Invoiced object")
 
-    def on_site_startup(self, site):
+    three_demo_areas = True
+    """
+    Whether the :fixture:`demo` fixture should generate three invoicing areas
+    instead of one.
+    """
+
+    def before_analyze(self):
+        # print("20210722 before_analyze()")
         from lino.core.utils import resolve_model
         self.item_model = resolve_model(self.item_model)
         # ivm = self.item_model._meta.get_field('voucher').remote_field.model
@@ -41,6 +57,8 @@ class Plugin(Plugin):
         #     raise Exception("voucher_model is {} but should be {}".format(
         #         self.voucher_model, ivm))
         self.voucher_model = resolve_model(self.voucher_model)
+        if self.order_model is not None:
+            self.order_model = resolve_model(self.order_model)
 
     def get_voucher_type(self):
         # from lino.core.utils import resolve_model
