@@ -284,10 +284,11 @@ class Plan(UserPlan):
                 # item.preview = ""
 
             # item.preview = "" # _("{} items").format(len(invoice_items))
-            total_amount = ZERO
+            # total_amount = ZERO
             for n, i in enumerate(invoice_items):
                 # i.discount_changed()
-                total_amount += i.get_amount() or ZERO
+                # total_amount += i.get_amount() or ZERO
+                item.amount += i.get_amount() or ZERO
                 # item.preview += "<br>\n"
                 # ctx = dict(
                 #     title=i.title or i.product,
@@ -309,7 +310,7 @@ class Plan(UserPlan):
                     item.preview += '...'
 
 
-            item.amount = total_amount
+            # item.amount = total_amount
             # item.number_of_invoiceables += 1
             item.full_clean()
             item.save()
