@@ -376,7 +376,7 @@ class ItemsByVoucher(dd.Table):
     master_key = 'voucher'
     order_by = ["seqno"]
     auto_fit_column_widths = True
-    # display_mode = 'html'
+    # display_mode_main = 'html'
     preview_limit = 0
 
 class VouchersByPartnerBase(dd.VirtualTable):
@@ -392,7 +392,7 @@ class VouchersByPartnerBase(dd.VirtualTable):
 
     order_by = ["-entry_date", '-id']
     master = 'contacts.Partner'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     _master_field_name = 'partner'
     # _voucher_base = PartnerRelated
