@@ -203,7 +203,7 @@ class StarsByController(Stars):
     label = _("Starred by")
     master_key = 'owner'
     column_names = "user *"
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     @classmethod
     def param_defaults(self, ar, **kw):
