@@ -166,7 +166,7 @@ class InterestsByPartner(Interests):
     master_key = 'partner'
     order_by = ["topic"]
     column_names = 'topic *'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     stay_in_grid = True
 
     insert_layout = dd.InsertLayout("""
@@ -189,7 +189,7 @@ class InterestsByController(Interests):
     order_by = ["topic"]
     column_names = 'topic *'
     stay_in_grid = True
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     insert_layout = dd.InsertLayout("""
     topic partner
     remark
